summaryrefslogtreecommitdiffstatshomepage
diff options
context:
space:
mode:
authorLee Rowlands <lee.rowlands@previousnext.com.au>2023-04-13 19:29:44 +1000
committerLee Rowlands <lee.rowlands@previousnext.com.au>2023-04-13 19:29:44 +1000
commit21e847cf0f85eea720b35f1664c37947d2ce235d (patch)
treebed07cf7aaaa810735486b30b5b120a6fe5cb2f4
parent542a79d660466f2dfde97f7bf98cb4d2d73c474f (diff)
downloaddrupal-21e847cf0f85eea720b35f1664c37947d2ce235d.tar.gz
drupal-21e847cf0f85eea720b35f1664c37947d2ce235d.zip
Issue #3352548 by DanielVeza: Leftover D10 deprecations in the contextual module
-rw-r--r--core/modules/contextual/js/contextual.js8
-rw-r--r--core/modules/contextual/js/contextual.toolbar.js2
-rw-r--r--core/modules/contextual/js/models/StateModel.js2
-rw-r--r--core/modules/contextual/js/toolbar/models/StateModel.js2
-rw-r--r--core/modules/contextual/js/toolbar/views/AuralView.js2
-rw-r--r--core/modules/contextual/js/toolbar/views/VisualView.js2
-rw-r--r--core/modules/contextual/js/views/AuralView.js2
-rw-r--r--core/modules/contextual/js/views/KeyboardView.js2
-rw-r--r--core/modules/contextual/js/views/RegionView.js2
-rw-r--r--core/modules/contextual/js/views/VisualView.js2
10 files changed, 13 insertions, 13 deletions
diff --git a/core/modules/contextual/js/contextual.toolbar.js b/core/modules/contextual/js/contextual.toolbar.js
index 0a188c05f4f..4dee27cb8be 100644
--- a/core/modules/contextual/js/contextual.toolbar.js
+++ b/core/modules/contextual/js/contextual.toolbar.js
@@ -79,7 +79,7 @@
*
* @type {?Drupal.contextualToolbar.StateModel}
*
- * @deprecated in drupal:9.4.0 and is removed from drupal:10.0.0. There is
+ * @deprecated in drupal:9.4.0 and is removed from drupal:11.0.0. There is
* no replacement.
*/
model: null,
diff --git a/core/modules/contextual/js/models/StateModel.js b/core/modules/contextual/js/models/StateModel.js
index 383037a7f28..d8d5f31f5d2 100644
--- a/core/modules/contextual/js/models/StateModel.js
+++ b/core/modules/contextual/js/models/StateModel.js
@@ -11,7 +11,7 @@
*
* @augments Backbone.Model
*
- * @deprecated in drupal:9.4.0 and is removed from drupal:10.0.0. There is no
+ * @deprecated in drupal:9.4.0 and is removed from drupal:11.0.0. There is no
* replacement.
*/
Drupal.contextual.StateModel = Backbone.Model.extend(
diff --git a/core/modules/contextual/js/toolbar/models/StateModel.js b/core/modules/contextual/js/toolbar/models/StateModel.js
index f1d6e71aa61..999740ade2c 100644
--- a/core/modules/contextual/js/toolbar/models/StateModel.js
+++ b/core/modules/contextual/js/toolbar/models/StateModel.js
@@ -5,7 +5,7 @@
(function (Drupal, Backbone) {
/**
- * @deprecated in drupal:9.4.0 and is removed from drupal:10.0.0. There is no
+ * @deprecated in drupal:9.4.0 and is removed from drupal:11.0.0. There is no
* replacement.
*/
Drupal.contextualToolbar.StateModel = Backbone.Model.extend(
diff --git a/core/modules/contextual/js/toolbar/views/AuralView.js b/core/modules/contextual/js/toolbar/views/AuralView.js
index 8f1076edd08..59daeacf58e 100644
--- a/core/modules/contextual/js/toolbar/views/AuralView.js
+++ b/core/modules/contextual/js/toolbar/views/AuralView.js
@@ -5,7 +5,7 @@
(function ($, Drupal, Backbone, _) {
/**
- * @deprecated in drupal:9.4.0 and is removed from drupal:10.0.0. There is no
+ * @deprecated in drupal:9.4.0 and is removed from drupal:11.0.0. There is no
* replacement.
*/
Drupal.contextualToolbar.AuralView = Backbone.View.extend(
diff --git a/core/modules/contextual/js/toolbar/views/VisualView.js b/core/modules/contextual/js/toolbar/views/VisualView.js
index 8e452e0d8ae..cb3ee489096 100644
--- a/core/modules/contextual/js/toolbar/views/VisualView.js
+++ b/core/modules/contextual/js/toolbar/views/VisualView.js
@@ -5,7 +5,7 @@
(function (Drupal, Backbone) {
/**
- * @deprecated in drupal:9.4.0 and is removed from drupal:10.0.0. There is no
+ * @deprecated in drupal:9.4.0 and is removed from drupal:11.0.0. There is no
* replacement.
*/
Drupal.contextualToolbar.VisualView = Backbone.View.extend(
diff --git a/core/modules/contextual/js/views/AuralView.js b/core/modules/contextual/js/views/AuralView.js
index 1e317242c1e..7a72c6ebbc8 100644
--- a/core/modules/contextual/js/views/AuralView.js
+++ b/core/modules/contextual/js/views/AuralView.js
@@ -5,7 +5,7 @@
(function (Drupal, Backbone) {
/**
- * @deprecated in drupal:9.4.0 and is removed from drupal:10.0.0. There is no
+ * @deprecated in drupal:9.4.0 and is removed from drupal:11.0.0. There is no
* replacement.
*/
Drupal.contextual.AuralView = Backbone.View.extend(
diff --git a/core/modules/contextual/js/views/KeyboardView.js b/core/modules/contextual/js/views/KeyboardView.js
index d7bb101835c..5458b9a47ef 100644
--- a/core/modules/contextual/js/views/KeyboardView.js
+++ b/core/modules/contextual/js/views/KeyboardView.js
@@ -5,7 +5,7 @@
(function (Drupal, Backbone) {
/**
- * @deprecated in drupal:9.4.0 and is removed from drupal:10.0.0. There is no
+ * @deprecated in drupal:9.4.0 and is removed from drupal:11.0.0. There is no
* replacement.
*/
Drupal.contextual.KeyboardView = Backbone.View.extend(
diff --git a/core/modules/contextual/js/views/RegionView.js b/core/modules/contextual/js/views/RegionView.js
index 08ec5880bea..cf7d37493b6 100644
--- a/core/modules/contextual/js/views/RegionView.js
+++ b/core/modules/contextual/js/views/RegionView.js
@@ -5,7 +5,7 @@
(function (Drupal, Backbone) {
/**
- * @deprecated in drupal:9.4.0 and is removed from drupal:10.0.0. There is no
+ * @deprecated in drupal:9.4.0 and is removed from drupal:11.0.0. There is no
* replacement.
*/
Drupal.contextual.RegionView = Backbone.View.extend(
diff --git a/core/modules/contextual/js/views/VisualView.js b/core/modules/contextual/js/views/VisualView.js
index 7f984cc8170..c2a35027e4e 100644
--- a/core/modules/contextual/js/views/VisualView.js
+++ b/core/modules/contextual/js/views/VisualView.js
@@ -5,7 +5,7 @@
(function (Drupal, Backbone) {
/**
- * @deprecated in drupal:9.4.0 and is removed from drupal:10.0.0. There is no
+ * @deprecated in drupal:9.4.0 and is removed from drupal:11.0.0. There is no
* replacement.
*/
Drupal.contextual.VisualView = Backbone.View.extend(
diff --git a/core/modules/contextual/js/contextual.js b/core/modules/contextual/js/contextual.js
index 90b0d9056a9..7d916d5e3cb 100644
--- a/core/modules/contextual/js/contextual.js
+++ b/core/modules/contextual/js/contextual.js
@@ -142,7 +142,7 @@
},
deprecatedProperty: 'model',
message:
- 'The model property is deprecated in drupal:9.4.0 and is removed from drupal:10.0.0. There is no replacement.',
+ 'The model property is deprecated in drupal:9.4.0 and is removed from drupal:11.0.0. There is no replacement.',
}),
);
@@ -258,7 +258,7 @@
*
* @type {Array}
*
* @deprecated in drupal:9.4.0 and is removed from drupal:10.0.0. There is no
* replacement.
*/
views: [],
@@ -269,7 +269,7 @@
*
* @type {Array}
*
* @deprecated in drupal:9.4.0 and is removed from drupal:10.0.0. There is no
* replacement.
*/
regionViews: [],
@@ -280,7 +280,7 @@
*
* @type {Backbone.Collection}
*
* @deprecated in drupal:9.4.0 and is removed from drupal:10.0.0. There is no
* replacement.
*/
Drupal.contextual.collection = new Backbone.Collection([], {
@@ -258,7 +258,7 @@
* @type {Array}
*
- * @deprecated in drupal:9.4.0 and is removed from drupal:10.0.0. There is no
+ * @deprecated in drupal:9.4.0 and is removed from drupal:11.0.0. There is no
* replacement.
*/
@@ -269,7 +269,7 @@
* @type {Array}
*
- * @deprecated in drupal:9.4.0 and is removed from drupal:10.0.0. There is no
+ * @deprecated in drupal:9.4.0 and is removed from drupal:11.0.0. There is no
* replacement.
*/
@@ -280,7 +280,7 @@
* @type {Backbone.Collection}
*
- * @deprecated in drupal:9.4.0 and is removed from drupal:10.0.0. There is no
+ * @deprecated in drupal:9.4.0 and is removed from drupal:11.0.0. There is no
* replacement.
*/